import 'bootstrap/dist/css/bootstrap.css';
import 'assets/css/style';

import Vue from 'vue';
import VueRouter from 'vue-router';
import VueResource from 'vue-resource';
import app from './app';
import routes from './routes';
import * as filters from 'utils/filters';
import VueLib from '../src';

Vue.use(VueRouter);
Vue.use(VueResource);
Vue.use(VueLib);

// 过滤器
Object.keys(filters).forEach(function (key) {
	Vue.filter(key, filters[key]);
});

/*
 * loading
 * 比如：
 * 多个异步
 * var request1 = this.$http.post(url, () => {});
 * var request2 = this.$http.post(url, () => {});
 * this._initLoading([request1, request2]);
 * 多个同步
 * var request1 = this.$http.post(url)
 * .then(() => {
 * 		return this.$http.post(url, () => {});
 * })
 * .then(() => {
 * 		// ...
 * });
 * this._initLoading([request1]);
 * 
 */
Vue.mixin({
    methods: {
        _initLoading(https) {
            this._showLoading();
            Promise.all(https).then(() => {
                this._hideLoading();
            });
        },
        _showLoading() {
            this.$Message.loading('正在加载中...', 0);
        },
        _hideLoading() {
            this.$Message.destroy();
        }
    }
});

var isFormData = function (obj) {
    return typeof FormData !== 'undefined' && obj instanceof FormData;
};
Vue.http.interceptors.push(function (request, next) {
    // Vue.http.options.emulateJSON = true
    if (!isFormData(request.body) && (Vue.util.isObject(request.body) || Vue.util.isArray(request.body))) {
        request.body = Vue.url.params(request.body);
        request.headers.set('Content-Type', 'application/x-www-form-urlencoded; charset=UTF-8');
    }
	
	/*
	 * 错误处理
	 * 接口形式如下：
	 * {"data":{},"errorMessage":null,"hasErrors":false,"success":true}
	 */
    next(function (response) {
		var suffix = 'url:' + response.url;
		var info = (text) => {
			if (this.$Message) this.$Message.destroy();
			this.$Message.error(text);
		};

        if (!response.ok) {
			info('服务器错误' + suffix);
        } else if (response.body.success === undefined) {
			info('没有数据' + suffix);
		} else if (response.body.hasErrors && response.body.errorMessage) {
			info(response.body.errorMessage + suffix);
        }

        return response;
	});
});

var router = new VueRouter({
	linkActiveClass: 'active',
	routes
});

new Vue({
	el: '#root',
	router,
    render(h) {
		return h(app);
	}
});

